===============================
OpenUpgrade Library
===============================

.. image:: https://img.shields.io/travis/OCA/openupgradelib.svg
        :target: https://travis-ci.org/OCA/openupgradelib

.. image:: https://img.shields.io/pypi/v/openupgradelib.svg
        :target: https://pypi.python.org/pypi/openupgradelib


A libary with support functions to be called from Odoo migration scripts.

* Free software: AGPL-3 license
* Documentation: https://openupgradelib.readthedocs.org.

Features
--------

* TODO
